From bf9ef33623713e4489eea7d410087e2763454a4f Mon Sep 17 00:00:00 2001 From: Travis CI Date: Sun, 16 Sep 2018 01:06:00 +0000 Subject: [PATCH] Deploy code docs to GitHub Pages Travis build: 376 Commit: d9ea67863adbb528218846fe70f48a3fe8100bc3 --- doxygen.log | 22 ++--- html/index.html | 27 +++--- html/keypoint_8hpp.html | 50 ++++++---- html/keypoint_8hpp.js | 20 ++-- html/keypoint_8hpp_source.html | 76 ++++++++------- html/namespacemembers.html | 2 +- html/namespacemembers_func.html | 2 +- html/namespacemembers_func_g.html | 10 +- html/namespacemembers_func_r.html | 2 +- html/namespacemembers_func_s.html | 4 +- html/namespacemembers_g.html | 10 +- html/namespacemembers_r.html | 2 +- html/namespacemembers_s.html | 4 +- html/namespaceop.html | 152 ++++++++++++++++++------------ html/navtreeindex6.js | 20 ++-- html/search/all_0.js | 2 +- html/search/all_11.js | 2 +- html/search/all_12.js | 4 +- html/search/all_6.js | 10 +- html/search/functions_0.js | 2 +- html/search/functions_11.js | 2 +- html/search/functions_12.js | 4 +- html/search/functions_6.js | 10 +- 23 files changed, 245 insertions(+), 194 deletions(-) diff --git a/doxygen.log b/doxygen.log index 7e508ea2..fa64c013 100644 --- a/doxygen.log +++ b/doxygen.log @@ -1185,17 +1185,17 @@ Generating docs for com/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/ /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:47: warning: unable to resolve reference to `doc/modules' for \ref command /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:49: warning: unable to resolve reference to `doc/released_features.md' for \ref command /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:49: warning: unable to resolve reference to `doc/release_notes.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:98: warning: unable to resolve reference to `doc/installation.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:107: warning: unable to resolve reference to `doc/demo_overview.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:117: warning: unable to resolve reference to `doc/modules/calibration_module.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:119: warning: unable to resolve reference to `examples/user_code/README.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:121: warning: unable to resolve reference to `doc/library_introduction.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:123: warning: unexpected token TK_EOF as the argument of ref -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:126: warning: unable to resolve reference to `doc/standalone_face_or_hand_keypoint_detector.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:99: warning: unable to resolve reference to `doc/installation.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:108: warning: unable to resolve reference to `doc/demo_overview.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:118: warning: unable to resolve reference to `doc/modules/calibration_module.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:120: warning: unable to resolve reference to `examples/user_code/README.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:122: warning: unable to resolve reference to `doc/library_introduction.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:124: warning: unexpected token TK_EOF as the argument of ref /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:127: warning: unable to resolve reference to `doc/standalone_face_or_hand_keypoint_detector.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:134: warning: unable to resolve reference to `doc/output.md' for \ref command -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:139: warning: explicit link request to 'speed' could not be resolved -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:164: warning: unable to resolve reference to `doc/contributors.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:128: warning: unable to resolve reference to `doc/standalone_face_or_hand_keypoint_detector.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:135: warning: unable to resolve reference to `doc/output.md' for \ref command +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:140: warning: explicit link request to 'speed' could not be resolved +/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/README.md:165: warning: unable to resolve reference to `doc/contributors.md' for \ref command pound op::WrapperStructHand... Generating docs for compound op::WrapperStructInput... Generating docs for compound op::WrapperStructOutput... @@ -1215,5 +1215,5 @@ Generating file index... Generating file member index... Generating example index... finalizing index lists... -lookup cache used 4881/65536 hits=37308 misses=5221 +lookup cache used 4881/65536 hits=37412 misses=5221 finished... diff --git a/html/index.html b/html/index.html index 7be4300d..3455f209 100644 --- a/html/index.html +++ b/html/index.html @@ -153,19 +153,6 @@ $(document).ready(function(){initNavTree('index.html','');});
  • Mar 2018: doc/modules/3d_reconstruction_module.md "**3-D keypoint reconstruction module**" (from multiple camera views)!
  • For further details, check all released features and release notes.

    -

    Contents

    -
      -
    1. Latest Features
    2. -
    3. Results
    4. -
    5. Installation, Reinstallation and Uninstallation
    6. -
    7. Quick Start
    8. -
    9. Output
    10. -
    11. Speeding Up OpenPose and Benchmark
    12. -
    13. Send Us Failure Cases and Feedback!
    14. -
    15. Authors and Contributors
    16. -
    17. Citation
    18. -
    19. License
    20. -

    Results

    Body-Foot Estimation

    <img src="doc/media/dance_foot.gif", width="360">

    @@ -177,6 +164,20 @@ $(document).ready(function(){initNavTree('index.html','');});

    <img src="doc/media/pose_hands.gif", width="360">

    Body Estimation

    <img src="doc/media/dance.gif", width="360">

    +

    Contents

    +
      +
    1. Features
    2. +
    3. Latest Features
    4. +
    5. Results
    6. +
    7. Installation, Reinstallation and Uninstallation
    8. +
    9. Quick Start
    10. +
    11. Output
    12. +
    13. Speeding Up OpenPose and Benchmark
    14. +
    15. Send Us Failure Cases and Feedback!
    16. +
    17. Authors and Contributors
    18. +
    19. Citation
    20. +
    21. License
    22. +

    Installation, Reinstallation and Uninstallation

    Windows portable version: Simply download and use the latest version from the Releases section.

    Otherwise, check doc/installation.md for instructions on how to build OpenPose from source.

    diff --git a/html/keypoint_8hpp.html b/html/keypoint_8hpp.html index 1d99434b..93b90334 100644 --- a/html/keypoint_8hpp.html +++ b/html/keypoint_8hpp.html @@ -121,26 +121,36 @@ Namespaces - - - - - - - - - - - - - - - - - - - - + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +

    Functions

    OP_API float op::getDistance (const Array< float > &keypoints, const int person, const int elementA, const int elementB)
     
    OP_API void op::averageKeypoints (Array< float > &keypointsA, const Array< float > &keypointsB, const int personA)
     
    OP_API void op::scaleKeypoints (Array< float > &keypoints, const float scale)
     
    OP_API void op::scaleKeypoints2d (Array< float > &keypoints, const float scaleX, const float scaleY)
     
    OP_API void op::scaleKeypoints2d (Array< float > &keypoints, const float scaleX, const float scaleY, const float offsetX, const float offsetY)
     
    OP_API void op::renderKeypointsCpu (Array< float > &frameArray, const Array< float > &keypoints, const std::vector< unsigned int > &pairs, const std::vector< float > colors, const float thicknessCircleRatio, const float thicknessLineRatioWRTCircle, const std::vector< float > &poseScales, const float threshold)
     
    OP_API Rectangle< float > op::getKeypointsRectangle (const Array< float > &keypoints, const int person, const float threshold)
     
    OP_API float op::getAverageScore (const Array< float > &keypoints, const int person)
     
    OP_API float op::getKeypointsArea (const Array< float > &keypoints, const int person, const float threshold)
     
    OP_API int op::getBiggestPerson (const Array< float > &keypoints, const float threshold)
     
    template<typename T >
    OP_API T op::getDistance (const Array< T > &keypoints, const int person, const int elementA, const int elementB)
     
    template<typename T >
    OP_API void op::averageKeypoints (Array< T > &keypointsA, const Array< T > &keypointsB, const int personA)
     
    template<typename T >
    OP_API void op::scaleKeypoints (Array< T > &keypoints, const T scale)
     
    template<typename T >
    OP_API void op::scaleKeypoints2d (Array< T > &keypoints, const T scaleX, const T scaleY)
     
    template<typename T >
    OP_API void op::scaleKeypoints2d (Array< T > &keypoints, const T scaleX, const T scaleY, const T offsetX, const T offsetY)
     
    template<typename T >
    OP_API void op::renderKeypointsCpu (Array< T > &frameArray, const Array< T > &keypoints, const std::vector< unsigned int > &pairs, const std::vector< T > colors, const T thicknessCircleRatio, const T thicknessLineRatioWRTCircle, const std::vector< T > &poseScales, const T threshold)
     
    template<typename T >
    OP_API Rectangle< T > op::getKeypointsRectangle (const Array< T > &keypoints, const int person, const T threshold)
     
    template<typename T >
    OP_API T op::getAverageScore (const Array< T > &keypoints, const int person)
     
    template<typename T >
    OP_API T op::getKeypointsArea (const Array< T > &keypoints, const int person, const T threshold)
     
    template<typename T >
    OP_API int op::getBiggestPerson (const Array< T > &keypoints, const T threshold)
     
    diff --git a/html/keypoint_8hpp.js b/html/keypoint_8hpp.js index 8a6a9aa8..1b7b7b9d 100644 --- a/html/keypoint_8hpp.js +++ b/html/keypoint_8hpp.js @@ -1,13 +1,13 @@ var keypoint_8hpp = [ - [ "averageKeypoints", "keypoint_8hpp.html#a5333b783eb8c9dbd4295d472a0dd44a4", null ], - [ "getAverageScore", "keypoint_8hpp.html#a29e26ec36e2ca8b8e0b7b6180f9315e3", null ], - [ "getBiggestPerson", "keypoint_8hpp.html#a22864d3d38f8020596d921951cf67750", null ], - [ "getDistance", "keypoint_8hpp.html#a88b83fabe52c73ed5c4f131c4ce75651", null ], - [ "getKeypointsArea", "keypoint_8hpp.html#aa2cc07e56f471c5e1d5f228c70ce6a05", null ], - [ "getKeypointsRectangle", "keypoint_8hpp.html#afb230634bc4a07f84ca91ebaf13e385f", null ], - [ "renderKeypointsCpu", "keypoint_8hpp.html#a07d0092a7c9ce5130cd26a7bbba927e9", null ], - [ "scaleKeypoints", "keypoint_8hpp.html#a0d3788b482df5017c8214d4f8cdaf660", null ], - [ "scaleKeypoints2d", "keypoint_8hpp.html#a3b9ff5158f47f76294936a0e0d861dca", null ], - [ "scaleKeypoints2d", "keypoint_8hpp.html#a5a53e61539f5f3e0a9c2d935fa2e8fff", null ] + [ "averageKeypoints", "keypoint_8hpp.html#a0f6ea912122004a238214f1de9c0ce03", null ], + [ "getAverageScore", "keypoint_8hpp.html#a18d1496d5696de69bbc06b66629291b8", null ], + [ "getBiggestPerson", "keypoint_8hpp.html#a07defc23ca50650a18a7239aa003cdb4", null ], + [ "getDistance", "keypoint_8hpp.html#a8ee375010f1614042da813e7ef12f948", null ], + [ "getKeypointsArea", "keypoint_8hpp.html#a12d134277a6ea41d997d3e900d3eb95a", null ], + [ "getKeypointsRectangle", "keypoint_8hpp.html#afb56b91b92d797394d7c3891b7e21816", null ], + [ "renderKeypointsCpu", "keypoint_8hpp.html#a7d083bc7f3ccd6ad6813970edbc8667f", null ], + [ "scaleKeypoints", "keypoint_8hpp.html#ac0249a6009da2fe5c0bfdb903002f510", null ], + [ "scaleKeypoints2d", "keypoint_8hpp.html#a64d6c9c2bb93893bcd99b305bbebcdbe", null ], + [ "scaleKeypoints2d", "keypoint_8hpp.html#a8836a6ec4c3a0dbc96436d110af661b4", null ] ]; \ No newline at end of file diff --git a/html/keypoint_8hpp_source.html b/html/keypoint_8hpp_source.html index d55cd14a..1401b185 100644 --- a/html/keypoint_8hpp_source.html +++ b/html/keypoint_8hpp_source.html @@ -114,44 +114,54 @@ $(document).ready(function(){initNavTree('keypoint_8hpp_source.html','');});
    5 
    6 namespace op
    7 {
    -
    8  OP_API float getDistance(const Array<float>& keypoints, const int person, const int elementA, const int elementB);
    -
    9 
    -
    10  OP_API void averageKeypoints(Array<float>& keypointsA, const Array<float>& keypointsB, const int personA);
    -
    11 
    -
    12  OP_API void scaleKeypoints(Array<float>& keypoints, const float scale);
    +
    8  template <typename T>
    +
    9  OP_API T getDistance(const Array<T>& keypoints, const int person, const int elementA, const int elementB);
    +
    10 
    +
    11  template <typename T>
    +
    12  OP_API void averageKeypoints(Array<T>& keypointsA, const Array<T>& keypointsB, const int personA);
    13 
    -
    14  OP_API void scaleKeypoints2d(Array<float>& keypoints, const float scaleX, const float scaleY);
    -
    15 
    -
    16  OP_API void scaleKeypoints2d(Array<float>& keypoints, const float scaleX, const float scaleY, const float offsetX,
    -
    17  const float offsetY);
    -
    18 
    -
    19  OP_API void renderKeypointsCpu(Array<float>& frameArray, const Array<float>& keypoints,
    -
    20  const std::vector<unsigned int>& pairs, const std::vector<float> colors,
    -
    21  const float thicknessCircleRatio, const float thicknessLineRatioWRTCircle,
    -
    22  const std::vector<float>& poseScales, const float threshold);
    +
    14  template <typename T>
    +
    15  OP_API void scaleKeypoints(Array<T>& keypoints, const T scale);
    +
    16 
    +
    17  template <typename T>
    +
    18  OP_API void scaleKeypoints2d(Array<T>& keypoints, const T scaleX, const T scaleY);
    +
    19 
    +
    20  template <typename T>
    +
    21  OP_API void scaleKeypoints2d(Array<T>& keypoints, const T scaleX, const T scaleY, const T offsetX,
    +
    22  const T offsetY);
    23 
    -
    24  OP_API Rectangle<float> getKeypointsRectangle(const Array<float>& keypoints, const int person,
    -
    25  const float threshold);
    -
    26 
    -
    27  OP_API float getAverageScore(const Array<float>& keypoints, const int person);
    -
    28 
    -
    29  OP_API float getKeypointsArea(const Array<float>& keypoints, const int person, const float threshold);
    -
    30 
    -
    31  OP_API int getBiggestPerson(const Array<float>& keypoints, const float threshold);
    -
    32 }
    +
    24  template <typename T>
    +
    25  OP_API void renderKeypointsCpu(Array<T>& frameArray, const Array<T>& keypoints,
    +
    26  const std::vector<unsigned int>& pairs, const std::vector<T> colors,
    +
    27  const T thicknessCircleRatio, const T thicknessLineRatioWRTCircle,
    +
    28  const std::vector<T>& poseScales, const T threshold);
    +
    29 
    +
    30  template <typename T>
    +
    31  OP_API Rectangle<T> getKeypointsRectangle(const Array<T>& keypoints, const int person,
    +
    32  const T threshold);
    33 
    -
    34 #endif // OPENPOSE_UTILITIES_KEYPOINT_HPP
    -
    OP_API float getKeypointsArea(const Array< float > &keypoints, const int person, const float threshold)
    -
    OP_API float getDistance(const Array< float > &keypoints, const int person, const int elementA, const int elementB)
    -
    OP_API float getAverageScore(const Array< float > &keypoints, const int person)
    -
    OP_API Rectangle< float > getKeypointsRectangle(const Array< float > &keypoints, const int person, const float threshold)
    -
    OP_API void renderKeypointsCpu(Array< float > &frameArray, const Array< float > &keypoints, const std::vector< unsigned int > &pairs, const std::vector< float > colors, const float thicknessCircleRatio, const float thicknessLineRatioWRTCircle, const std::vector< float > &poseScales, const float threshold)
    +
    34  template <typename T>
    +
    35  OP_API T getAverageScore(const Array<T>& keypoints, const int person);
    +
    36 
    +
    37  template <typename T>
    +
    38  OP_API T getKeypointsArea(const Array<T>& keypoints, const int person, const T threshold);
    +
    39 
    +
    40  template <typename T>
    +
    41  OP_API int getBiggestPerson(const Array<T>& keypoints, const T threshold);
    +
    42 }
    +
    43 
    +
    44 #endif // OPENPOSE_UTILITIES_KEYPOINT_HPP
    +
    OP_API Rectangle< T > getKeypointsRectangle(const Array< T > &keypoints, const int person, const T threshold)
    +
    OP_API T getDistance(const Array< T > &keypoints, const int person, const int elementA, const int elementB)
    +
    OP_API void renderKeypointsCpu(Array< T > &frameArray, const Array< T > &keypoints, const std::vector< unsigned int > &pairs, const std::vector< T > colors, const T thicknessCircleRatio, const T thicknessLineRatioWRTCircle, const std::vector< T > &poseScales, const T threshold)
    +
    OP_API T getKeypointsArea(const Array< T > &keypoints, const int person, const T threshold)
    -
    OP_API void scaleKeypoints2d(Array< float > &keypoints, const float scaleX, const float scaleY)
    -
    OP_API void averageKeypoints(Array< float > &keypointsA, const Array< float > &keypointsB, const int personA)
    -
    OP_API void scaleKeypoints(Array< float > &keypoints, const float scale)
    -
    OP_API int getBiggestPerson(const Array< float > &keypoints, const float threshold)
    +
    OP_API void averageKeypoints(Array< T > &keypointsA, const Array< T > &keypointsB, const int personA)
    +
    OP_API T getAverageScore(const Array< T > &keypoints, const int person)
    +
    OP_API void scaleKeypoints2d(Array< T > &keypoints, const T scaleX, const T scaleY)
    +
    OP_API int getBiggestPerson(const Array< T > &keypoints, const T threshold)
    #define OP_API
    Definition: macros.hpp:16
    +
    OP_API void scaleKeypoints(Array< T > &keypoints, const T scale)
    diff --git a/html/namespacemembers.html b/html/namespacemembers.html index a68e636b..239d33fe 100644 --- a/html/namespacemembers.html +++ b/html/namespacemembers.html @@ -179,7 +179,7 @@ $(document).ready(function(){initNavTree('namespacemembers.html','');}); : op
  • averageKeypoints() -: op +: op
  • diff --git a/html/namespacemembers_func.html b/html/namespacemembers_func.html index a0428407..1a56c8c0 100644 --- a/html/namespacemembers_func.html +++ b/html/namespacemembers_func.html @@ -145,7 +145,7 @@ $(document).ready(function(){initNavTree('namespacemembers_func.html','');}); : cl
  • averageKeypoints() -: op +: op
  • diff --git a/html/namespacemembers_func_g.html b/html/namespacemembers_func_g.html index 0cfb16af..2015f5bf 100644 --- a/html/namespacemembers_func_g.html +++ b/html/namespacemembers_func_g.html @@ -142,16 +142,16 @@ $(document).ready(function(){initNavTree('namespacemembers_func_g.html','');}); : op
  • getAverageScore() -: op +: op
  • getBiggestPerson() -: op +: op
  • getCudaGpuNumber() : op
  • getDistance() -: op +: op
  • getFileExtension() : op @@ -184,10 +184,10 @@ $(document).ready(function(){initNavTree('namespacemembers_func_g.html','');}); : cl::detail
  • getKeypointsArea() -: op +: op
  • getKeypointsRectangle() -: op +: op
  • getLastNumber() : op diff --git a/html/namespacemembers_func_r.html b/html/namespacemembers_func_r.html index 2fc01710..dfb9d4c8 100644 --- a/html/namespacemembers_func_r.html +++ b/html/namespacemembers_func_r.html @@ -163,7 +163,7 @@ $(document).ready(function(){initNavTree('namespacemembers_func_r.html','');}); : op
  • renderKeypointsCpu() -: op +: op
  • renderPoseDistance() : op diff --git a/html/namespacemembers_func_s.html b/html/namespacemembers_func_s.html index 2e004646..dad053a5 100644 --- a/html/namespacemembers_func_s.html +++ b/html/namespacemembers_func_s.html @@ -151,10 +151,10 @@ $(document).ready(function(){initNavTree('namespacemembers_func_s.html','');}); : op
  • scaleKeypoints() -: op +: op
  • scaleKeypoints2d() -: op +: op
  • sCharRound() : op diff --git a/html/namespacemembers_g.html b/html/namespacemembers_g.html index 67f6a302..520008aa 100644 --- a/html/namespacemembers_g.html +++ b/html/namespacemembers_g.html @@ -149,16 +149,16 @@ $(document).ready(function(){initNavTree('namespacemembers_g.html','');}); : op
  • getAverageScore() -: op +: op
  • getBiggestPerson() -: op +: op
  • getCudaGpuNumber() : op
  • getDistance() -: op +: op
  • getFileExtension() : op @@ -191,10 +191,10 @@ $(document).ready(function(){initNavTree('namespacemembers_g.html','');}); : cl::detail
  • getKeypointsArea() -: op +: op
  • getKeypointsRectangle() -: op +: op
  • getLastNumber() : op diff --git a/html/namespacemembers_r.html b/html/namespacemembers_r.html index 5a0a86ce..e5aa38fa 100644 --- a/html/namespacemembers_r.html +++ b/html/namespacemembers_r.html @@ -170,7 +170,7 @@ $(document).ready(function(){initNavTree('namespacemembers_r.html','');}); : op
  • renderKeypointsCpu() -: op +: op
  • RenderMode : op diff --git a/html/namespacemembers_s.html b/html/namespacemembers_s.html index a28ec575..6ecfcd6b 100644 --- a/html/namespacemembers_s.html +++ b/html/namespacemembers_s.html @@ -158,10 +158,10 @@ $(document).ready(function(){initNavTree('namespacemembers_s.html','');}); : op
  • scaleKeypoints() -: op +: op
  • scaleKeypoints2d() -: op +: op
  • ScaleMode : op diff --git a/html/namespaceop.html b/html/namespaceop.html index 1cc52076..1992167b 100644 --- a/html/namespaceop.html +++ b/html/namespaceop.html @@ -899,26 +899,36 @@ int, 4 >   OP_API Point< int > flagsToPoint (const std::string &pointString, const std::string &pointExample="1280x720")   -OP_API float getDistance (const Array< float > &keypoints, const int person, const int elementA, const int elementB) -  -OP_API void averageKeypoints (Array< float > &keypointsA, const Array< float > &keypointsB, const int personA) -  -OP_API void scaleKeypoints (Array< float > &keypoints, const float scale) -  -OP_API void scaleKeypoints2d (Array< float > &keypoints, const float scaleX, const float scaleY) -  -OP_API void scaleKeypoints2d (Array< float > &keypoints, const float scaleX, const float scaleY, const float offsetX, const float offsetY) -  -OP_API void renderKeypointsCpu (Array< float > &frameArray, const Array< float > &keypoints, const std::vector< unsigned int > &pairs, const std::vector< float > colors, const float thicknessCircleRatio, const float thicknessLineRatioWRTCircle, const std::vector< float > &poseScales, const float threshold) -  -OP_API Rectangle< float > getKeypointsRectangle (const Array< float > &keypoints, const int person, const float threshold) -  -OP_API float getAverageScore (const Array< float > &keypoints, const int person) -  -OP_API float getKeypointsArea (const Array< float > &keypoints, const int person, const float threshold) -  -OP_API int getBiggestPerson (const Array< float > &keypoints, const float threshold) -  +template<typename T > +OP_API T getDistance (const Array< T > &keypoints, const int person, const int elementA, const int elementB) +  +template<typename T > +OP_API void averageKeypoints (Array< T > &keypointsA, const Array< T > &keypointsB, const int personA) +  +template<typename T > +OP_API void scaleKeypoints (Array< T > &keypoints, const T scale) +  +template<typename T > +OP_API void scaleKeypoints2d (Array< T > &keypoints, const T scaleX, const T scaleY) +  +template<typename T > +OP_API void scaleKeypoints2d (Array< T > &keypoints, const T scaleX, const T scaleY, const T offsetX, const T offsetY) +  +template<typename T > +OP_API void renderKeypointsCpu (Array< T > &frameArray, const Array< T > &keypoints, const std::vector< unsigned int > &pairs, const std::vector< T > colors, const T thicknessCircleRatio, const T thicknessLineRatioWRTCircle, const std::vector< T > &poseScales, const T threshold) +  +template<typename T > +OP_API Rectangle< T > getKeypointsRectangle (const Array< T > &keypoints, const int person, const T threshold) +  +template<typename T > +OP_API T getAverageScore (const Array< T > &keypoints, const int person) +  +template<typename T > +OP_API T getKeypointsArea (const Array< T > &keypoints, const int person, const T threshold) +  +template<typename T > +OP_API int getBiggestPerson (const Array< T > &keypoints, const T threshold) +  OP_API void putTextOnCvMat (cv::Mat &cvMat, const std::string &textToDisplay, const Point< int > &position, const cv::Scalar &color, const bool normalizeWidth, const int imageWidth)   OP_API void unrollArrayToUCharCvMat (cv::Mat &cvMatResult, const Array< float > &array) @@ -1640,20 +1650,22 @@ Variables

    Function Documentation

    - +
    +
    +template<typename T >
    - + - + @@ -3934,14 +3946,16 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API void op::averageKeypoints (Array< float > & Array< T > &  keypointsA,
    const Array< float > & const Array< T > &  keypointsB,
    - + - + @@ -3960,20 +3974,22 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API float op::getAverageScore OP_API T op::getAverageScore (const Array< float > & const Array< T > &  keypoints,
    - + - + @@ -4001,14 +4017,16 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API int op::getBiggestPerson (const Array< float > & const Array< T > &  keypoints,
    const float const T  threshold 
    - + - + @@ -4259,14 +4277,16 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API float op::getDistance OP_API T op::getDistance (const Array< float > & const Array< T > &  keypoints,
    - + - + @@ -4278,7 +4298,7 @@ template<typename T > - + @@ -4291,14 +4311,16 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API float op::getKeypointsArea OP_API T op::getKeypointsArea (const Array< float > & const Array< T > &  keypoints,
    const float const T  threshold 
    - + - + @@ -4310,7 +4332,7 @@ template<typename T > - + @@ -5982,20 +6004,22 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API Rectangle<float> op::getKeypointsRectangle OP_API Rectangle<T> op::getKeypointsRectangle (const Array< float > & const Array< T > &  keypoints,
    const float const T  threshold 
    - + - + @@ -6007,31 +6031,31 @@ template<typename T > - + - + - + - + - + @@ -6954,20 +6978,22 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API void op::renderKeypointsCpu (Array< float > & Array< T > &  frameArray,
    const Array< float > & const Array< T > &  keypoints,
    const std::vector< float > const std::vector< T >  colors,
    const float const T  thicknessCircleRatio,
    const float const T  thicknessLineRatioWRTCircle,
    const std::vector< float > & const std::vector< T > &  poseScales,
    const float const T  threshold 
    - + - + @@ -6980,26 +7006,28 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API void op::scaleKeypoints (Array< float > & Array< T > &  keypoints,
    const float const T  scale 
    - + - + - + @@ -7012,38 +7040,40 @@ template<typename T > - +
    +
    +template<typename T >
    OP_API void op::scaleKeypoints2d (Array< float > & Array< T > &  keypoints,
    const float const T  scaleX,
    const float const T  scaleY 
    - + - + - + - + - + diff --git a/html/navtreeindex6.js b/html/navtreeindex6.js index 05b67547..177de044 100644 --- a/html/navtreeindex6.js +++ b/html/navtreeindex6.js @@ -137,16 +137,16 @@ var NAVTREEINDEX6 = "keep_top_n_people_8hpp.html":[2,0,0,0,2,8], "keep_top_n_people_8hpp_source.html":[2,0,0,0,2,8], "keypoint_8hpp.html":[2,0,0,0,13,7], -"keypoint_8hpp.html#a07d0092a7c9ce5130cd26a7bbba927e9":[2,0,0,0,13,7,6], -"keypoint_8hpp.html#a0d3788b482df5017c8214d4f8cdaf660":[2,0,0,0,13,7,7], -"keypoint_8hpp.html#a22864d3d38f8020596d921951cf67750":[2,0,0,0,13,7,2], -"keypoint_8hpp.html#a29e26ec36e2ca8b8e0b7b6180f9315e3":[2,0,0,0,13,7,1], -"keypoint_8hpp.html#a3b9ff5158f47f76294936a0e0d861dca":[2,0,0,0,13,7,8], -"keypoint_8hpp.html#a5333b783eb8c9dbd4295d472a0dd44a4":[2,0,0,0,13,7,0], -"keypoint_8hpp.html#a5a53e61539f5f3e0a9c2d935fa2e8fff":[2,0,0,0,13,7,9], -"keypoint_8hpp.html#a88b83fabe52c73ed5c4f131c4ce75651":[2,0,0,0,13,7,3], -"keypoint_8hpp.html#aa2cc07e56f471c5e1d5f228c70ce6a05":[2,0,0,0,13,7,4], -"keypoint_8hpp.html#afb230634bc4a07f84ca91ebaf13e385f":[2,0,0,0,13,7,5], +"keypoint_8hpp.html#a07defc23ca50650a18a7239aa003cdb4":[2,0,0,0,13,7,2], +"keypoint_8hpp.html#a0f6ea912122004a238214f1de9c0ce03":[2,0,0,0,13,7,0], +"keypoint_8hpp.html#a12d134277a6ea41d997d3e900d3eb95a":[2,0,0,0,13,7,4], +"keypoint_8hpp.html#a18d1496d5696de69bbc06b66629291b8":[2,0,0,0,13,7,1], +"keypoint_8hpp.html#a64d6c9c2bb93893bcd99b305bbebcdbe":[2,0,0,0,13,7,8], +"keypoint_8hpp.html#a7d083bc7f3ccd6ad6813970edbc8667f":[2,0,0,0,13,7,6], +"keypoint_8hpp.html#a8836a6ec4c3a0dbc96436d110af661b4":[2,0,0,0,13,7,9], +"keypoint_8hpp.html#a8ee375010f1614042da813e7ef12f948":[2,0,0,0,13,7,3], +"keypoint_8hpp.html#ac0249a6009da2fe5c0bfdb903002f510":[2,0,0,0,13,7,7], +"keypoint_8hpp.html#afb56b91b92d797394d7c3891b7e21816":[2,0,0,0,13,7,5], "keypoint_8hpp_source.html":[2,0,0,0,13,7], "keypoint_saver_8hpp.html":[2,0,0,0,4,9], "keypoint_saver_8hpp_source.html":[2,0,0,0,4,9], diff --git a/html/search/all_0.js b/html/search/all_0.js index 1839dadb..cb4cc210 100644 --- a/html/search/all_0.js +++ b/html/search/all_0.js @@ -35,5 +35,5 @@ var searchData= ['at',['at',['../classop_1_1_array.html#a6e0afd5f447efbfc29efbeac62716eff',1,'op::Array::at(const int index)'],['../classop_1_1_array.html#a95e83e3379fd43460db68c2adb61f981',1,'op::Array::at(const int index) const '],['../classop_1_1_array.html#a8eebb6c34642cdf19ac74c7ed38d128b',1,'op::Array::at(const std::vector< int > &indexes)'],['../classop_1_1_array.html#a5cb014203b418de3996b90597df53b6e',1,'op::Array::at(const std::vector< int > &indexes) const ']]], ['atomic_5fsvm_5fvector',['atomic_svm_vector',['../namespacecl.html#a67195ada68c22c3c3711e2b8e7330944',1,'cl']]], ['autorepeat',['AutoRepeat',['../namespaceop.html#abc501c56c6cf6cf1989c84b1692cb774a3ebbca1b84060b0caaf823639739945d',1,'op']]], - ['averagekeypoints',['averageKeypoints',['../namespaceop.html#a5333b783eb8c9dbd4295d472a0dd44a4',1,'op']]] + ['averagekeypoints',['averageKeypoints',['../namespaceop.html#a0f6ea912122004a238214f1de9c0ce03',1,'op']]] ]; diff --git a/html/search/all_11.js b/html/search/all_11.js index 6309126f..520d704b 100644 --- a/html/search/all_11.js +++ b/html/search/all_11.js @@ -42,7 +42,7 @@ var searchData= ['renderhandinherited',['renderHandInherited',['../classop_1_1_hand_cpu_renderer.html#ae9e43ff22b0aae81dd88df3a313b0b0f',1,'op::HandCpuRenderer::renderHandInherited()'],['../classop_1_1_hand_gpu_renderer.html#a8206b59519e8214e06af9994a6038dae',1,'op::HandGpuRenderer::renderHandInherited()']]], ['renderhandkeypointscpu',['renderHandKeypointsCpu',['../namespaceop.html#afb5b711819f94b51f32460861d9cea38',1,'op']]], ['renderhandkeypointsgpu',['renderHandKeypointsGpu',['../namespaceop.html#a74458454b8bec064b435a3bde5ad25e0',1,'op']]], - ['renderkeypointscpu',['renderKeypointsCpu',['../namespaceop.html#a07d0092a7c9ce5130cd26a7bbba927e9',1,'op']]], + ['renderkeypointscpu',['renderKeypointsCpu',['../namespaceop.html#a7d083bc7f3ccd6ad6813970edbc8667f',1,'op']]], ['rendermode',['renderMode',['../structop_1_1_wrapper_struct_face.html#accc6e564598130b9bf0a6d0ec9c304c4',1,'op::WrapperStructFace::renderMode()'],['../structop_1_1_wrapper_struct_hand.html#a90ddd24ee55b6aabd9a1728ccd91525e',1,'op::WrapperStructHand::renderMode()'],['../structop_1_1_wrapper_struct_pose.html#ad6b5ea0cef8eb81d20ab39099ba7716e',1,'op::WrapperStructPose::renderMode()'],['../namespaceop.html#afce557f02e337e16150d00bdf72ec033',1,'op::RenderMode()']]], ['renderpose',['renderPose',['../classop_1_1_pose_cpu_renderer.html#a98541b982847713472411402314efd96',1,'op::PoseCpuRenderer::renderPose()'],['../classop_1_1_pose_gpu_renderer.html#a4705b3c47cd9ac8174e357999960a28f',1,'op::PoseGpuRenderer::renderPose()'],['../classop_1_1_pose_renderer.html#ad1e96ceb47bf205b56b50c6b2792f9e3',1,'op::PoseRenderer::renderPose()']]], ['renderpose_2ehpp',['renderPose.hpp',['../render_pose_8hpp.html',1,'']]], diff --git a/html/search/all_12.js b/html/search/all_12.js index 0b62e5bd..76a8f8a0 100644 --- a/html/search/all_12.js +++ b/html/search/all_12.js @@ -17,8 +17,8 @@ var searchData= ['scalegap',['scaleGap',['../structop_1_1_wrapper_struct_pose.html#a646ae142f821411d22d772b76960d585',1,'op::WrapperStructPose']]], ['scaleinputtonetinputs',['scaleInputToNetInputs',['../structop_1_1_datum.html#a0e416771f275be98c83aaff01e482a71',1,'op::Datum']]], ['scaleinputtooutput',['scaleInputToOutput',['../structop_1_1_datum.html#a6cf96c250c236a03f13da69e1d4336d9',1,'op::Datum']]], - ['scalekeypoints',['scaleKeypoints',['../namespaceop.html#a0d3788b482df5017c8214d4f8cdaf660',1,'op']]], - ['scalekeypoints2d',['scaleKeypoints2d',['../namespaceop.html#a3b9ff5158f47f76294936a0e0d861dca',1,'op::scaleKeypoints2d(Array< float > &keypoints, const float scaleX, const float scaleY)'],['../namespaceop.html#a5a53e61539f5f3e0a9c2d935fa2e8fff',1,'op::scaleKeypoints2d(Array< float > &keypoints, const float scaleX, const float scaleY, const float offsetX, const float offsetY)']]], + ['scalekeypoints',['scaleKeypoints',['../namespaceop.html#ac0249a6009da2fe5c0bfdb903002f510',1,'op']]], + ['scalekeypoints2d',['scaleKeypoints2d',['../namespaceop.html#a64d6c9c2bb93893bcd99b305bbebcdbe',1,'op::scaleKeypoints2d(Array< T > &keypoints, const T scaleX, const T scaleY)'],['../namespaceop.html#a8836a6ec4c3a0dbc96436d110af661b4',1,'op::scaleKeypoints2d(Array< T > &keypoints, const T scaleX, const T scaleY, const T offsetX, const T offsetY)']]], ['scalemode',['ScaleMode',['../namespaceop.html#af72fe4ed32846c12f41b049d3d0e1bda',1,'op']]], ['scalenettooutput',['scaleNetToOutput',['../structop_1_1_datum.html#a44af7162e180c6856ce909057f43d8e1',1,'op::Datum']]], ['scalerange',['scaleRange',['../structop_1_1_wrapper_struct_hand.html#adaea15e182e5c75129293873cd94e35f',1,'op::WrapperStructHand']]], diff --git a/html/search/all_6.js b/html/search/all_6.js index 49907531..11740573 100644 --- a/html/search/all_6.js +++ b/html/search/all_6.js @@ -5,8 +5,8 @@ var searchData= ['getalphaheatmap',['getAlphaHeatMap',['../classop_1_1_renderer.html#a503d7fdba655b14348769ad3f69b6c00',1,'op::Renderer']]], ['getalphakeypoint',['getAlphaKeypoint',['../classop_1_1_renderer.html#ac4df12764776ba2e27c71a3c4181f647',1,'op::Renderer']]], ['getarginfo',['getArgInfo',['../classcl_1_1_kernel.html#afbc480bee6ff22d0ebfb907e7a9f5700',1,'cl::Kernel::getArgInfo(cl_uint argIndex, cl_kernel_arg_info name, T *param) const '],['../classcl_1_1_kernel.html#aeaa426d11ca0195646b563fda918c3e1',1,'cl::Kernel::getArgInfo(cl_uint argIndex, cl_int *err=NULL) const ']]], - ['getaveragescore',['getAverageScore',['../namespaceop.html#a29e26ec36e2ca8b8e0b7b6180f9315e3',1,'op']]], - ['getbiggestperson',['getBiggestPerson',['../namespaceop.html#a22864d3d38f8020596d921951cf67750',1,'op']]], + ['getaveragescore',['getAverageScore',['../namespaceop.html#a18d1496d5696de69bbc06b66629291b8',1,'op']]], + ['getbiggestperson',['getBiggestPerson',['../namespaceop.html#a07defc23ca50650a18a7239aa003cdb4',1,'op']]], ['getblendoriginalframe',['getBlendOriginalFrame',['../classop_1_1_renderer.html#a8e0739fb55d61fc76918ca3fb6ac3bc4',1,'op::Renderer']]], ['getbuildinfo',['getBuildInfo',['../classcl_1_1_program.html#a51c723551c01ef55f6222c84d58578fc',1,'cl::Program::getBuildInfo(const Device &device, cl_program_build_info name, T *param) const '],['../classcl_1_1_program.html#a06f673e6c88aac6c5e9f754e830028b6',1,'cl::Program::getBuildInfo(const Device &device, cl_int *err=NULL) const '],['../classcl_1_1_program.html#aea803c4bba50b6a01d76537d946e211f',1,'cl::Program::getBuildInfo(cl_int *err=NULL) const ']]], ['getcameradistortions',['getCameraDistortions',['../classop_1_1_camera_parameter_reader.html#a3ce10a02969515039e8575c3c044f882',1,'op::CameraParameterReader']]], @@ -23,7 +23,7 @@ var searchData= ['getcvmat',['getCvMat',['../classop_1_1_array.html#ac817621e848601cf7d6571e75d8f6865',1,'op::Array']]], ['getdefault',['getDefault',['../classcl_1_1_device.html#a7428cf3cdccc824c414730ed65e40a0d',1,'cl::Device::getDefault()'],['../classcl_1_1_platform.html#a01bea413d721189214cc59cfbc5d092d',1,'cl::Platform::getDefault()'],['../classcl_1_1_context.html#ad180f6f7d8b5a95710ab72f96162b051',1,'cl::Context::getDefault()'],['../classcl_1_1_command_queue.html#a24444b0dbd7cc0eb2bce126c9ccbac4c',1,'cl::CommandQueue::getDefault()']]], ['getdevices',['getDevices',['../classcl_1_1_platform.html#abf18ee63c06c9cbec5931fe391071b14',1,'cl::Platform']]], - ['getdistance',['getDistance',['../namespaceop.html#a88b83fabe52c73ed5c4f131c4ce75651',1,'op']]], + ['getdistance',['getDistance',['../namespaceop.html#a8ee375010f1614042da813e7ef12f948',1,'op']]], ['getenabled',['getEnabled',['../classop_1_1_face_extractor_net.html#a7756f22df265a9967453f22f606aa256',1,'op::FaceExtractorNet::getEnabled()'],['../classop_1_1_hand_extractor_net.html#ade5c1f40a02ff6d0c5e3e5b9dab00088',1,'op::HandExtractorNet::getEnabled()']]], ['geterrormodes',['getErrorModes',['../classop_1_1_configure_error.html#a4ece0fc7d4f34752959cad3a3b6dcf9d',1,'op::ConfigureError']]], ['getfacekeypoints',['getFaceKeypoints',['../classop_1_1_face_extractor_net.html#a5a20063d945e40214ea9f6635a73ba17',1,'op::FaceExtractorNet']]], @@ -50,8 +50,8 @@ var searchData= ['getinfohelper',['getInfoHelper',['../classcl_1_1detail_1_1_wrapper.html#a17726beb74f709c3ed5ac06ac2737c3e',1,'cl::detail::Wrapper::getInfoHelper()'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a17726beb74f709c3ed5ac06ac2737c3e',1,'cl::detail::Wrapper< cl_device_id >::getInfoHelper()'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a973484a071d325cce40155782841dcfe',1,'cl::detail::Wrapper< cl_device_id >::getInfoHelper()'],['../namespacecl_1_1detail.html#a5fa0595cfd70a34a662283c683f58bb1',1,'cl::detail::getInfoHelper(Functor f, cl_uint name, T *param, long)'],['../namespacecl_1_1detail.html#a0900b1581dac237cebb4dbc385471316',1,'cl::detail::getInfoHelper(Func f, cl_uint name, vector< vector< unsigned char >> *param, int)'],['../namespacecl_1_1detail.html#a1fd04ddf2303bc88b61ecc84478f6c89',1,'cl::detail::getInfoHelper(Func f, cl_uint name, vector< T > *param, long)'],['../namespacecl_1_1detail.html#a66d6678a19540f0202f534a25b00b06f',1,'cl::detail::getInfoHelper(Func f, cl_uint name, vector< T > *param, int, typename T::cl_type=0)'],['../namespacecl_1_1detail.html#a06a46d0b30e2a0653391e74f31d684c6',1,'cl::detail::getInfoHelper(Func f, cl_uint name, string *param, long)'],['../namespacecl_1_1detail.html#ae190233f2424c5bba4be566ccf8abcc5',1,'cl::detail::getInfoHelper(Func f, cl_uint name, array< size_type, N > *param, long)'],['../namespacecl_1_1detail.html#abcfe70e7b9beebd31b874fc0e59ab147',1,'cl::detail::getInfoHelper(Func f, cl_uint name, T *param, int, typename T::cl_type=0)']]], ['getisrunningsharedptr',['getIsRunningSharedPtr',['../classop_1_1_thread_manager.html#a48ea53b3de4d09c84db18e2c31ce1be1',1,'op::ThreadManager']]], ['getkernel',['getKernel',['../classcl_1_1_kernel_functor.html#aea980d414c52e07f67070119c91f8523',1,'cl::KernelFunctor']]], - ['getkeypointsarea',['getKeypointsArea',['../namespaceop.html#aa2cc07e56f471c5e1d5f228c70ce6a05',1,'op']]], - ['getkeypointsrectangle',['getKeypointsRectangle',['../namespaceop.html#afb230634bc4a07f84ca91ebaf13e385f',1,'op']]], + ['getkeypointsarea',['getKeypointsArea',['../namespaceop.html#a12d134277a6ea41d997d3e900d3eb95a',1,'op']]], + ['getkeypointsrectangle',['getKeypointsRectangle',['../namespaceop.html#afb56b91b92d797394d7c3891b7e21816',1,'op']]], ['getlastnumber',['getLastNumber',['../namespaceop.html#ab670c693d8e4a540cfe75ce8383b6d10',1,'op']]], ['getlogmodes',['getLogModes',['../classop_1_1_configure_log.html#a01eebce325f7e401601804d58fd3a2b2',1,'op::ConfigureLog']]], ['getmaxsize',['getMaxSize',['../classop_1_1_queue_base.html#a25255992523051f7d2a82694ffe7a1cf',1,'op::QueueBase']]], diff --git a/html/search/functions_0.js b/html/search/functions_0.js index 9a6028d1..03d163a1 100644 --- a/html/search/functions_0.js +++ b/html/search/functions_0.js @@ -13,5 +13,5 @@ var searchData= ['arrayclose',['arrayClose',['../classop_1_1_json_ofstream.html#a3f940d3ad51d0acb7126d62a5617fd69',1,'op::JsonOfstream']]], ['arrayopen',['arrayOpen',['../classop_1_1_json_ofstream.html#a4cc6d50256354b3dc7385e2db01aabc0',1,'op::JsonOfstream']]], ['at',['at',['../classop_1_1_array.html#a6e0afd5f447efbfc29efbeac62716eff',1,'op::Array::at(const int index)'],['../classop_1_1_array.html#a95e83e3379fd43460db68c2adb61f981',1,'op::Array::at(const int index) const '],['../classop_1_1_array.html#a8eebb6c34642cdf19ac74c7ed38d128b',1,'op::Array::at(const std::vector< int > &indexes)'],['../classop_1_1_array.html#a5cb014203b418de3996b90597df53b6e',1,'op::Array::at(const std::vector< int > &indexes) const ']]], - ['averagekeypoints',['averageKeypoints',['../namespaceop.html#a5333b783eb8c9dbd4295d472a0dd44a4',1,'op']]] + ['averagekeypoints',['averageKeypoints',['../namespaceop.html#a0f6ea912122004a238214f1de9c0ce03',1,'op']]] ]; diff --git a/html/search/functions_11.js b/html/search/functions_11.js index b247cfba..12ff38b7 100644 --- a/html/search/functions_11.js +++ b/html/search/functions_11.js @@ -18,7 +18,7 @@ var searchData= ['renderhandinherited',['renderHandInherited',['../classop_1_1_hand_cpu_renderer.html#ae9e43ff22b0aae81dd88df3a313b0b0f',1,'op::HandCpuRenderer::renderHandInherited()'],['../classop_1_1_hand_gpu_renderer.html#a8206b59519e8214e06af9994a6038dae',1,'op::HandGpuRenderer::renderHandInherited()']]], ['renderhandkeypointscpu',['renderHandKeypointsCpu',['../namespaceop.html#afb5b711819f94b51f32460861d9cea38',1,'op']]], ['renderhandkeypointsgpu',['renderHandKeypointsGpu',['../namespaceop.html#a74458454b8bec064b435a3bde5ad25e0',1,'op']]], - ['renderkeypointscpu',['renderKeypointsCpu',['../namespaceop.html#a07d0092a7c9ce5130cd26a7bbba927e9',1,'op']]], + ['renderkeypointscpu',['renderKeypointsCpu',['../namespaceop.html#a7d083bc7f3ccd6ad6813970edbc8667f',1,'op']]], ['renderpose',['renderPose',['../classop_1_1_pose_cpu_renderer.html#a98541b982847713472411402314efd96',1,'op::PoseCpuRenderer::renderPose()'],['../classop_1_1_pose_gpu_renderer.html#a4705b3c47cd9ac8174e357999960a28f',1,'op::PoseGpuRenderer::renderPose()'],['../classop_1_1_pose_renderer.html#ad1e96ceb47bf205b56b50c6b2792f9e3',1,'op::PoseRenderer::renderPose()']]], ['renderposedistance',['renderPoseDistance',['../namespaceop.html#ae45299199877cae41fb2c71ab65d4508',1,'op']]], ['renderposeheatmapgpu',['renderPoseHeatMapGpu',['../namespaceop.html#a1f851b71bd5136ae78a1b63ddb228ed4',1,'op']]], diff --git a/html/search/functions_12.js b/html/search/functions_12.js index 47d74f05..dbd94dd6 100644 --- a/html/search/functions_12.js +++ b/html/search/functions_12.js @@ -11,8 +11,8 @@ var searchData= ['savepeoplejson',['savePeopleJson',['../namespaceop.html#af9c189f7c80092570699c8b9d5686fea',1,'op::savePeopleJson(const Array< float > &keypoints, const std::vector< std::vector< std::array< float, 3 >>> &candidates, const std::string &keypointName, const std::string &fileName, const bool humanReadable)'],['../namespaceop.html#a1e986a510a29bfd8c682f65a8b399551',1,'op::savePeopleJson(const std::vector< std::pair< Array< float >, std::string >> &keypointVector, const std::vector< std::vector< std::array< float, 3 >>> &candidates, const std::string &fileName, const bool humanReadable)']]], ['scale',['scale',['../classop_1_1_keypoint_scaler.html#ab85b497b5676c72c4bd62eaef98ec56c',1,'op::KeypointScaler::scale(Array< float > &arrayToScale, const double scaleInputToOutput, const double scaleNetToOutput, const Point< int > &producerSize) const '],['../classop_1_1_keypoint_scaler.html#accfefe6f4be7d2886c3720b751b4c36a',1,'op::KeypointScaler::scale(std::vector< Array< float >> &arraysToScale, const double scaleInputToOutput, const double scaleNetToOutput, const Point< int > &producerSize) const '],['../classop_1_1_keypoint_scaler.html#a3766338315f1364515b3bf8bf4d02701',1,'op::KeypointScaler::scale(std::vector< std::vector< std::array< float, 3 >>> &poseCandidates, const double scaleInputToOutput, const double scaleNetToOutput, const Point< int > &producerSize) const ']]], ['scaleandsizeextractor',['ScaleAndSizeExtractor',['../classop_1_1_scale_and_size_extractor.html#a9ec53a73ac8a72d3c94cf998b4794d7b',1,'op::ScaleAndSizeExtractor']]], - ['scalekeypoints',['scaleKeypoints',['../namespaceop.html#a0d3788b482df5017c8214d4f8cdaf660',1,'op']]], - ['scalekeypoints2d',['scaleKeypoints2d',['../namespaceop.html#a3b9ff5158f47f76294936a0e0d861dca',1,'op::scaleKeypoints2d(Array< float > &keypoints, const float scaleX, const float scaleY)'],['../namespaceop.html#a5a53e61539f5f3e0a9c2d935fa2e8fff',1,'op::scaleKeypoints2d(Array< float > &keypoints, const float scaleX, const float scaleY, const float offsetX, const float offsetY)']]], + ['scalekeypoints',['scaleKeypoints',['../namespaceop.html#ac0249a6009da2fe5c0bfdb903002f510',1,'op']]], + ['scalekeypoints2d',['scaleKeypoints2d',['../namespaceop.html#a64d6c9c2bb93893bcd99b305bbebcdbe',1,'op::scaleKeypoints2d(Array< T > &keypoints, const T scaleX, const T scaleY)'],['../namespaceop.html#a8836a6ec4c3a0dbc96436d110af661b4',1,'op::scaleKeypoints2d(Array< T > &keypoints, const T scaleX, const T scaleY, const T offsetX, const T offsetY)']]], ['scharround',['sCharRound',['../namespaceop.html#a65c35aa5a4461e819a01371f152a7407',1,'op']]], ['sendjointangles',['sendJointAngles',['../classop_1_1_udp_sender.html#a2e8b52e1fd5a3383ebc9063ce21f6f06',1,'op::UdpSender']]], ['set',['set',['../classop_1_1_pose_extractor_net.html#a7e49f2339e21ff784689ec78c9d69b75',1,'op::PoseExtractorNet::set()'],['../classop_1_1_flir_reader.html#af14f63c79272781429341dc3a0720485',1,'op::FlirReader::set()'],['../classop_1_1_image_directory_reader.html#a1965a4dca2ddb86b24e69e2da90b9dbf',1,'op::ImageDirectoryReader::set()'],['../classop_1_1_ip_camera_reader.html#ac13cc7da97a31d8e69eaa64b2a7b31ba',1,'op::IpCameraReader::set()'],['../classop_1_1_producer.html#ab30c7b3e34d962e0b17458d9a0947f6b',1,'op::Producer::set(const int capProperty, const double value)=0'],['../classop_1_1_producer.html#af11f1bbfbd61b9534c02c3e4839e19b0',1,'op::Producer::set(const ProducerProperty property, const double value)'],['../classop_1_1_video_capture_reader.html#ab2929b7d2d002b58ebaf7b9b56999cca',1,'op::VideoCaptureReader::set()'],['../classop_1_1_video_reader.html#a0dd53334327642368d41ec860e64e756',1,'op::VideoReader::set()'],['../classop_1_1_webcam_reader.html#ae66b26829cc2d6e3f02109d4431a7bc2',1,'op::WebcamReader::set()']]], diff --git a/html/search/functions_6.js b/html/search/functions_6.js index 3901ff99..0f682327 100644 --- a/html/search/functions_6.js +++ b/html/search/functions_6.js @@ -5,8 +5,8 @@ var searchData= ['getalphaheatmap',['getAlphaHeatMap',['../classop_1_1_renderer.html#a503d7fdba655b14348769ad3f69b6c00',1,'op::Renderer']]], ['getalphakeypoint',['getAlphaKeypoint',['../classop_1_1_renderer.html#ac4df12764776ba2e27c71a3c4181f647',1,'op::Renderer']]], ['getarginfo',['getArgInfo',['../classcl_1_1_kernel.html#afbc480bee6ff22d0ebfb907e7a9f5700',1,'cl::Kernel::getArgInfo(cl_uint argIndex, cl_kernel_arg_info name, T *param) const '],['../classcl_1_1_kernel.html#aeaa426d11ca0195646b563fda918c3e1',1,'cl::Kernel::getArgInfo(cl_uint argIndex, cl_int *err=NULL) const ']]], - ['getaveragescore',['getAverageScore',['../namespaceop.html#a29e26ec36e2ca8b8e0b7b6180f9315e3',1,'op']]], - ['getbiggestperson',['getBiggestPerson',['../namespaceop.html#a22864d3d38f8020596d921951cf67750',1,'op']]], + ['getaveragescore',['getAverageScore',['../namespaceop.html#a18d1496d5696de69bbc06b66629291b8',1,'op']]], + ['getbiggestperson',['getBiggestPerson',['../namespaceop.html#a07defc23ca50650a18a7239aa003cdb4',1,'op']]], ['getblendoriginalframe',['getBlendOriginalFrame',['../classop_1_1_renderer.html#a8e0739fb55d61fc76918ca3fb6ac3bc4',1,'op::Renderer']]], ['getbuildinfo',['getBuildInfo',['../classcl_1_1_program.html#a51c723551c01ef55f6222c84d58578fc',1,'cl::Program::getBuildInfo(const Device &device, cl_program_build_info name, T *param) const '],['../classcl_1_1_program.html#a06f673e6c88aac6c5e9f754e830028b6',1,'cl::Program::getBuildInfo(const Device &device, cl_int *err=NULL) const '],['../classcl_1_1_program.html#aea803c4bba50b6a01d76537d946e211f',1,'cl::Program::getBuildInfo(cl_int *err=NULL) const ']]], ['getcameradistortions',['getCameraDistortions',['../classop_1_1_camera_parameter_reader.html#a3ce10a02969515039e8575c3c044f882',1,'op::CameraParameterReader']]], @@ -23,7 +23,7 @@ var searchData= ['getcvmat',['getCvMat',['../classop_1_1_array.html#ac817621e848601cf7d6571e75d8f6865',1,'op::Array']]], ['getdefault',['getDefault',['../classcl_1_1_device.html#a7428cf3cdccc824c414730ed65e40a0d',1,'cl::Device::getDefault()'],['../classcl_1_1_platform.html#a01bea413d721189214cc59cfbc5d092d',1,'cl::Platform::getDefault()'],['../classcl_1_1_context.html#ad180f6f7d8b5a95710ab72f96162b051',1,'cl::Context::getDefault()'],['../classcl_1_1_command_queue.html#a24444b0dbd7cc0eb2bce126c9ccbac4c',1,'cl::CommandQueue::getDefault()']]], ['getdevices',['getDevices',['../classcl_1_1_platform.html#abf18ee63c06c9cbec5931fe391071b14',1,'cl::Platform']]], - ['getdistance',['getDistance',['../namespaceop.html#a88b83fabe52c73ed5c4f131c4ce75651',1,'op']]], + ['getdistance',['getDistance',['../namespaceop.html#a8ee375010f1614042da813e7ef12f948',1,'op']]], ['getenabled',['getEnabled',['../classop_1_1_face_extractor_net.html#a7756f22df265a9967453f22f606aa256',1,'op::FaceExtractorNet::getEnabled()'],['../classop_1_1_hand_extractor_net.html#ade5c1f40a02ff6d0c5e3e5b9dab00088',1,'op::HandExtractorNet::getEnabled()']]], ['geterrormodes',['getErrorModes',['../classop_1_1_configure_error.html#a4ece0fc7d4f34752959cad3a3b6dcf9d',1,'op::ConfigureError']]], ['getfacekeypoints',['getFaceKeypoints',['../classop_1_1_face_extractor_net.html#a5a20063d945e40214ea9f6635a73ba17',1,'op::FaceExtractorNet']]], @@ -48,8 +48,8 @@ var searchData= ['getinfohelper',['getInfoHelper',['../namespacecl_1_1detail.html#a5fa0595cfd70a34a662283c683f58bb1',1,'cl::detail::getInfoHelper(Functor f, cl_uint name, T *param, long)'],['../namespacecl_1_1detail.html#a0900b1581dac237cebb4dbc385471316',1,'cl::detail::getInfoHelper(Func f, cl_uint name, vector< vector< unsigned char >> *param, int)'],['../namespacecl_1_1detail.html#a1fd04ddf2303bc88b61ecc84478f6c89',1,'cl::detail::getInfoHelper(Func f, cl_uint name, vector< T > *param, long)'],['../namespacecl_1_1detail.html#a66d6678a19540f0202f534a25b00b06f',1,'cl::detail::getInfoHelper(Func f, cl_uint name, vector< T > *param, int, typename T::cl_type=0)'],['../namespacecl_1_1detail.html#a06a46d0b30e2a0653391e74f31d684c6',1,'cl::detail::getInfoHelper(Func f, cl_uint name, string *param, long)'],['../namespacecl_1_1detail.html#ae190233f2424c5bba4be566ccf8abcc5',1,'cl::detail::getInfoHelper(Func f, cl_uint name, array< size_type, N > *param, long)'],['../namespacecl_1_1detail.html#abcfe70e7b9beebd31b874fc0e59ab147',1,'cl::detail::getInfoHelper(Func f, cl_uint name, T *param, int, typename T::cl_type=0)']]], ['getisrunningsharedptr',['getIsRunningSharedPtr',['../classop_1_1_thread_manager.html#a48ea53b3de4d09c84db18e2c31ce1be1',1,'op::ThreadManager']]], ['getkernel',['getKernel',['../classcl_1_1_kernel_functor.html#aea980d414c52e07f67070119c91f8523',1,'cl::KernelFunctor']]], - ['getkeypointsarea',['getKeypointsArea',['../namespaceop.html#aa2cc07e56f471c5e1d5f228c70ce6a05',1,'op']]], - ['getkeypointsrectangle',['getKeypointsRectangle',['../namespaceop.html#afb230634bc4a07f84ca91ebaf13e385f',1,'op']]], + ['getkeypointsarea',['getKeypointsArea',['../namespaceop.html#a12d134277a6ea41d997d3e900d3eb95a',1,'op']]], + ['getkeypointsrectangle',['getKeypointsRectangle',['../namespaceop.html#afb56b91b92d797394d7c3891b7e21816',1,'op']]], ['getlastnumber',['getLastNumber',['../namespaceop.html#ab670c693d8e4a540cfe75ce8383b6d10',1,'op']]], ['getlogmodes',['getLogModes',['../classop_1_1_configure_log.html#a01eebce325f7e401601804d58fd3a2b2',1,'op::ConfigureLog']]], ['getmaxsize',['getMaxSize',['../classop_1_1_queue_base.html#a25255992523051f7d2a82694ffe7a1cf',1,'op::QueueBase']]],
    OP_API void op::scaleKeypoints2d (Array< float > & Array< T > &  keypoints,
    const float const T  scaleX,
    const float const T  scaleY,
    const float const T  offsetX,
    const float const T  offsetY